[Libreoffice-commits] core.git: include/svx include/xmloff odk/docs odk/examples offapi/com officecfg/registry qadevOOo/tests sd/source svx/source xmloff/source

rocso (via logerrit) logerrit at kemper.freedesktop.org
Fri Sep 17 10:54:13 UTC 2021


 include/svx/strings.hrc                                                  |   10 ++---
 include/svx/svddrag.hxx                                                  |    8 ++--
 include/svx/svdmrkv.hxx                                                  |   16 ++++----
 include/svx/svdobj.hxx                                                   |    6 +--
 include/svx/svdoedge.hxx                                                 |   18 ++++-----
 include/svx/svdpntv.hxx                                                  |    8 ++--
 include/svx/svdview.hxx                                                  |    4 +-
 include/xmloff/shapeimport.hxx                                           |    8 ++--
 odk/docs/idl/idl_chapter_refs.txt                                        |    2 -
 odk/examples/DevelopersGuide/Drawing/GluePointDemo.java                  |    4 +-
 odk/examples/DevelopersGuide/Drawing/Organigram.java                     |    4 +-
 offapi/com/sun/star/drawing/ConnectorShape.idl                           |    4 +-
 offapi/com/sun/star/drawing/EnhancedCustomShapeGluePointType.idl         |   10 ++---
 offapi/com/sun/star/drawing/EnhancedCustomShapePath.idl                  |    2 -
 offapi/com/sun/star/drawing/EscapeDirection.idl                          |    2 -
 offapi/com/sun/star/drawing/GluePoint2.idl                               |   14 +++----
 offapi/com/sun/star/drawing/Shape.idl                                    |    2 -
 officecfg/registry/data/org/openoffice/Office/UI/DrawImpressCommands.xcu |   20 +++++-----
 officecfg/registry/data/org/openoffice/Office/UI/DrawWindowState.xcu     |    4 +-
 officecfg/registry/data/org/openoffice/Office/UI/ImpressWindowState.xcu  |    2 -
 qadevOOo/tests/java/ifc/drawing/_XGluePointsSupplier.java                |    2 -
 sd/source/ui/dlg/gluectrl.cxx                                            |    4 +-
 sd/source/ui/func/fuconbez.cxx                                           |    2 -
 sd/source/ui/func/fuediglu.cxx                                           |    8 ++--
 sd/source/ui/func/fusel.cxx                                              |    8 ++--
 sd/source/ui/view/drviews4.cxx                                           |    4 +-
 sd/source/ui/view/drviews7.cxx                                           |    2 -
 svx/source/engine3d/obj3d.cxx                                            |    6 +--
 svx/source/engine3d/scene3d.cxx                                          |    6 +--
 svx/source/inc/svdobjplusdata.hxx                                        |    2 -
 svx/source/svdraw/svdcrtv.cxx                                            |    2 -
 svx/source/svdraw/svddrgmt.cxx                                           |    2 -
 svx/source/svdraw/svddrgv.cxx                                            |    4 +-
 svx/source/svdraw/svdglue.cxx                                            |    4 +-
 svx/source/svdraw/svdhdl.cxx                                             |    2 -
 svx/source/svdraw/svdmrkv.cxx                                            |    2 -
 svx/source/svdraw/svdmrkv1.cxx                                           |    4 +-
 svx/source/svdraw/svdobj.cxx                                             |   12 +++---
 svx/source/svdraw/svdoedge.cxx                                           |   12 +++---
 svx/source/svdraw/svdview.cxx                                            |    4 +-
 svx/source/unodraw/gluepts.cxx                                           |   12 +++---
 xmloff/source/draw/shapeexport.cxx                                       |    4 +-
 xmloff/source/draw/shapeimport.cxx                                       |   12 +++---
 xmloff/source/draw/ximpshap.cxx                                          |    4 +-
 44 files changed, 136 insertions(+), 136 deletions(-)

New commits:
commit 4f7560240d8a9273fd5ecbc76e7ac054b3a6e4ae
Author:     rocso <ross.johnson at homemail.com.au>
AuthorDate: Fri Sep 17 17:12:37 2021 +1000
Commit:     Heiko Tietze <heiko.tietze at documentfoundation.org>
CommitDate: Fri Sep 17 12:53:38 2021 +0200

    tdf#143550 - use the term "gluepoints" consistently
    
    Change-Id: Id10dc2ef13f54a148a800003cc4bd88ca1a0056f
    Reviewed-on: https://gerrit.libreoffice.org/c/core/+/122233
    Tested-by: Jenkins
    Reviewed-by: Heiko Tietze <heiko.tietze at documentfoundation.org>

diff --git a/include/svx/strings.hrc b/include/svx/strings.hrc
index 915c84762686..1b30c31fa1a0 100644
--- a/include/svx/strings.hrc
+++ b/include/svx/strings.hrc
@@ -206,7 +206,7 @@
 #define STR_EditImportMtf                                   NC_("STR_EditImportMtf", "Split %1")
 #define STR_ExchangePaste                                   NC_("STR_ExchangePaste", "Insert object(s)")
 #define STR_DragInsertPoint                                 NC_("STR_DragInsertPoint", "Insert point to %1")
-#define STR_DragInsertGluePoint                             NC_("STR_DragInsertGluePoint", "Insert glue point to %1")
+#define STR_DragInsertGluePoint                             NC_("STR_DragInsertGluePoint", "Insert gluepoint to %1")
 #define STR_DragMethMovHdl                                  NC_("STR_DragMethMovHdl", "Move reference-point")
 #define STR_DragMethObjOwn                                  NC_("STR_DragMethObjOwn", "Geometrically change %1")
 #define STR_DragMethMove                                    NC_("STR_DragMethMove", "Move %1")
@@ -234,14 +234,14 @@
 #define STR_ViewMarked                                      NC_("STR_ViewMarked", "%1 selected")
 #define STR_ViewMarkedPoint                                 NC_("STR_ViewMarkedPoint", "Point from %1")
 #define STR_ViewMarkedPoints                                NC_("STR_ViewMarkedPoints", "%2 points from %1")
-#define STR_ViewMarkedGluePoint                             NC_("STR_ViewMarkedGluePoint", "Glue point from %1")
-#define STR_ViewMarkedGluePoints                            NC_("STR_ViewMarkedGluePoints", "%2 glue points from %1")
+#define STR_ViewMarkedGluePoint                             NC_("STR_ViewMarkedGluePoint", "Gluepoint from %1")
+#define STR_ViewMarkedGluePoints                            NC_("STR_ViewMarkedGluePoints", "%2 gluepoints from %1")
 #define STR_ViewMarkObjs                                    NC_("STR_ViewMarkObjs", "Mark objects")
 #define STR_ViewMarkMoreObjs                                NC_("STR_ViewMarkMoreObjs", "Mark additional objects")
 #define STR_ViewMarkPoints                                  NC_("STR_ViewMarkPoints", "Mark points")
 #define STR_ViewMarkMorePoints                              NC_("STR_ViewMarkMorePoints", "Mark additional points")
-#define STR_ViewMarkGluePoints                              NC_("STR_ViewMarkGluePoints", "Mark glue points")
-#define STR_ViewMarkMoreGluePoints                          NC_("STR_ViewMarkMoreGluePoints", "Mark additional glue points")
+#define STR_ViewMarkGluePoints                              NC_("STR_ViewMarkGluePoints", "Mark gluepoints")
+#define STR_ViewMarkMoreGluePoints                          NC_("STR_ViewMarkMoreGluePoints", "Mark additional gluepoints")
 #define STR_ViewCreateObj                                   NC_("STR_ViewCreateObj", "Create %1")
 #define STR_UndoInsertObj                                   NC_("STR_UndoInsertObj", "Insert %1")
 #define STR_UndoCopyObj                                     NC_("STR_UndoCopyObj", "Copy %1")
diff --git a/include/svx/svddrag.hxx b/include/svx/svddrag.hxx
index 6718e5f36b5d..5a1d8d16af48 100644
--- a/include/svx/svddrag.hxx
+++ b/include/svx/svddrag.hxx
@@ -80,10 +80,10 @@ class SVXCORE_DLLPUBLIC SdrDragStat final
     sal_Int32 GetPrevPos() const { return mvPnts.size()-(mvPnts.size()>1 ? 2 : 1); }
 
     // This is passed all the way through to ApplySpecialDrag of the Edge Object
-    // For LOK, we cannot really specify which glue point to select by default
-    // It selects the nearest glue points after DragEnd event.
-    // When multiple objects are on top of each other or somehow their glue points
-    // collide, the glue point is selected from the lowest order numbered object
+    // For LOK, we cannot really specify which gluepoint to select by default
+    // It selects the nearest gluepoints after DragEnd event.
+    // When multiple objects are on top of each other or somehow their gluepoints
+    // collide, the gluepoint is selected from the lowest order numbered object
     // We can pass the ord number information inside the draginfo and choose the correct shape
     struct {
         sal_Int32 objectOrdNum = -1;
diff --git a/include/svx/svdmrkv.hxx b/include/svx/svdmrkv.hxx
index bdd1046c097d..58f38d594c89 100644
--- a/include/svx/svdmrkv.hxx
+++ b/include/svx/svdmrkv.hxx
@@ -60,7 +60,7 @@ enum class SdrHitKind
     Object,          // Hit
     Handle,          // Marking handle
     HelpLine,        // Reference line
-    Gluepoint,       // Glue point
+    Gluepoint,       // Gluepoint
     TextEdit,        // Open OutlinerView was hit
     TextEditObj,     // Object for SdrBeginTextEdit (Textbereich)
     UrlField,        // Field in TextObj was hit (while it is currently not edited)
@@ -73,7 +73,7 @@ enum class SdrHitKind
 enum class SdrViewEditMode {
     Edit,           // Also known as arrow or pointer mode
     Create,         // Tool for object creation
-    GluePointEdit   // Glue point editing mode
+    GluePointEdit   // Gluepoint editing mode
 };
 
 /** options for ImpGetDescriptionString() */
@@ -199,7 +199,7 @@ public:
     virtual void HideSdrPage() override;
     bool IsObjMarkable(SdrObject const * pObj, SdrPageView const * pPV) const;
 
-    // Returns sal_True if objects, points or glue points are selected by drawing a frame
+    // Returns sal_True if objects, points or gluepoints are selected by drawing a frame
     // (as long as the frame is drawn).
     bool IsMarking() const { return IsMarkObj() || IsMarkPoints() || IsMarkGluePoints(); }
 
@@ -369,13 +369,13 @@ public:
 
     // A gluepoint is clearly identified by the SdrObject
     // (to which it belongs) as well as by a sal_uInt16 nId (as each SdrObject may consist of
-    // several glue points. Here at the View there is an additional
+    // several gluepoints. Here at the View there is an additional
     // SdrPageView, which should be defined correctly always.
     // Alternatively a gluepoint may be characterized by a SdrHdl.
     // In this case the SdrHdl instance consists of all required information.
-    // And in this case, the glue point are always is marked by enforcement
+    // And in this case, the gluepoint are always is marked by enforcement
     // (Handlers are just situated at marked gluepoints )
-    // Attention: With each change of the glue point status the handle list is re-calculated.
+    // Attention: With each change of the gluepoint status the handle list is re-calculated.
     // All previously saved SdrHdl* became invalid by this, the same with the point IDs!
     bool PickGluePoint(const Point& rPnt, SdrObject*& rpObj, sal_uInt16& rnId, SdrPageView*& rpPV) const;
     bool MarkGluePoint(const SdrObject* pObj, sal_uInt16 nId, bool bUnmark);
@@ -396,7 +396,7 @@ public:
     // P1 is deleted, a mark is set at P2.
     void MarkNextGluePoint();
 
-    // Draw a selection frame for glue point marking.
+    // Draw a selection frame for gluepoint marking.
     // This routine will just be started in case that HasMarkablePoints() returns sal_True.
     // The GlueEditMode sal_True is disregarded.
     // bool BegMarkGluePoints(const Point& rPnt, OutputDevice* pOut);
@@ -415,7 +415,7 @@ public:
     const tools::Rectangle& GetMarkedObjRect() const; // SnapRects of Objects, without line width
     tools::Rectangle GetMarkedObjBoundRect() const;   // incl. line width, overlapping rags, ...
     const tools::Rectangle& GetMarkedPointsRect() const;     // Enclosing rectangle of all marked points
-    const tools::Rectangle& GetMarkedGluePointsRect() const; // Enclosing rectangle of all marked glue points
+    const tools::Rectangle& GetMarkedGluePointsRect() const; // Enclosing rectangle of all marked gluepoints
     const tools::Rectangle& GetAllMarkedRect() const { return GetMarkedObjRect(); }
     tools::Rectangle GetAllMarkedBoundRect() const { return GetMarkedObjBoundRect(); }
 
diff --git a/include/svx/svdobj.hxx b/include/svx/svdobj.hxx
index 760f53f3a019..a5aa10aa7c66 100644
--- a/include/svx/svdobj.hxx
+++ b/include/svx/svdobj.hxx
@@ -650,7 +650,7 @@ public:
     // (see also documentation in SvdoEdge.hxx, SdrEdgeObj, as well as SvdGlue.hxx and SvdGlEV.hxx)
     //
     // There are nodes and edges. In theory an edge can also be a node, but this isn't implemented yet.
-    // A node has a number of glue points, onto which edges can glued to
+    // A node has a number of gluepoints, onto which edges can glued to
     // An edge can be either
     // - without any connection to any node,
     // - or connected on one end to a node, while the other end is not connected,
@@ -660,7 +660,7 @@ public:
     // This is also true for SetGluePoint()... on the node.
     // On the other hand, moving/resizing an edge breaks the connection.
 
-    // automatic glue points:
+    // automatic gluepoints:
     // a node object must provide four vertex and corner positions
     // usually 0: top, 1: right, 2: bottom, 3: left
     virtual SdrGluePoint GetVertexGluePoint(sal_uInt16 nNum) const;
@@ -669,7 +669,7 @@ public:
     // 0: top-left, 1: top-right, 2: bottom-right, 3: bottom-left
     virtual SdrGluePoint GetCornerGluePoint(sal_uInt16 nNum) const;
 
-    // list of all glue points, can be NULL
+    // list of all gluepoints, can be NULL
     virtual const SdrGluePointList* GetGluePointList() const;
 
     // after changing the GluePointList, one has to call the object's SendRepaintBroadcast!
diff --git a/include/svx/svdoedge.hxx b/include/svx/svdoedge.hxx
index ee0e64b08281..455d72f74014 100644
--- a/include/svx/svdoedge.hxx
+++ b/include/svx/svdoedge.hxx
@@ -362,7 +362,7 @@ public:
  // SdrView). SdrEdgeObj::Move() itself does not remove the
  // connection.
  //
- // Each node object can have connectors, so-called glue points. These
+ // Each node object can have connectors, so-called gluepoints. These
  // are the geometric points at which the connecting edge object ends
  // when the connection is established. By default, each object has no
  // connectors.  Nevertheless, one can dock an edge in certain view
@@ -380,32 +380,32 @@ public:
  // used from the offering of connectors of the object or/and of the
  // vertices. The user assigns this attribute by docking the node in
  // its center (see, e.g., Visio).
- // 09-06-1996: bUseBestConnector uses vertex glue points only.
+ // 09-06-1996: bUseBestConnector uses vertex gluepoints only.
  //
  // And here is some terminology:
  //   Connector : The connector object (edge object)
  //   Node      : Any object to which a connector can be glued to, e.g., a rectangle,
  //               etc.
- //   Glue point: The point at which the connector is glued to the node object.
+ //   Gluepoint: The point at which the connector is glued to the node object.
  //               There are:
- //                 Vertex glue points: Each node object presents these glue
+ //                 Vertex gluepoints: Each node object presents these glue
  //                     points inherently. Perhaps there is already the option
  //                     "automatically glue to object vertex" in Draw (default is
  //                     on).
- //                 Corner glue points: These glue points, too, are already
+ //                 Corner gluepoints: These gluepoints, too, are already
  //                     auto-enabled on objects. Similar to the ones above,
  //                     there may already be an option for them in Draw (default is
  //                     off).
- //                 In contrast to Visio, vertex glue points and corner glue
+ //                 In contrast to Visio, vertex gluepoints and corner glue
  //                     points are not displayed in the UI; they are simply there (if
  //                     the option is activated).
- //                 Custom glue points: Any number of them are present on each
+ //                 Custom gluepoints: Any number of them are present on each
  //                     node object. They can be made visible using the option
  //                     (always visible when editing). At the moment, however, they
  //                     are not yet fully implemented.
- //                 Automatic glue point selection: If the connector is docked
+ //                 Automatic gluepoint selection: If the connector is docked
  //                     to the node object so that the black frame encompasses the
  //                     entire object, then the connector tries to find the most
- //                     convenient of the 4 vertex glue points (and only of those).
+ //                     convenient of the 4 vertex gluepoints (and only of those).
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/include/svx/svdpntv.hxx b/include/svx/svdpntv.hxx
index 15ae50d9222a..048c5f6b5cd8 100644
--- a/include/svx/svdpntv.hxx
+++ b/include/svx/svdpntv.hxx
@@ -157,10 +157,10 @@ protected:
     bool                        mbGridFront : 1;
     bool                        mbHlplVisible : 1;
     bool                        mbHlplFront : 1;
-    bool                        mbGlueVisible : 1;    // Persistent; show glue points
-    bool                        mbGlueVisible2 : 1;   // Also show glue points for GluePointEdit
-    bool                        mbGlueVisible3 : 1;   // Also show glue points for EdgeTool
-    bool                        mbGlueVisible4 : 1;   // Show glue points, if one edge is selected
+    bool                        mbGlueVisible : 1;    // Persistent; show gluepoints
+    bool                        mbGlueVisible2 : 1;   // Also show gluepoints for GluePointEdit
+    bool                        mbGlueVisible3 : 1;   // Also show gluepoints for EdgeTool
+    bool                        mbGlueVisible4 : 1;   // Show gluepoints, if one edge is selected
     bool                        mbSomeObjChgdFlag : 1;
     bool                        mbSwapAsynchron : 1;
     bool                        mbPrintPreview : 1;
diff --git a/include/svx/svdview.hxx b/include/svx/svdview.hxx
index 7043f0f75131..83c780b431ec 100644
--- a/include/svx/svdview.hxx
+++ b/include/svx/svdview.hxx
@@ -206,7 +206,7 @@ public:
     // The methods consider the particular context:
     // - simple drawing
     // - mode for editing points
-    // - mode for editing glue points
+    // - mode for editing gluepoints
     // - TextEdit
     // - ... to be continued
     void MarkAll();
@@ -216,7 +216,7 @@ public:
 
     virtual void DeleteMarked();
 
-    // Marking objects, traverse stations or glue points (depending on view-
+    // Marking objects, traverse stations or gluepoints (depending on view-
     // context) by enveloping the selection frame.
     //   bAddMark=TRUE: add to existing selection (->Shift)
     //   bUnmark=TRUE: remove objects from selection which are inside of
diff --git a/odk/docs/idl/idl_chapter_refs.txt b/odk/docs/idl/idl_chapter_refs.txt
index 875ce811c309..169dd60ba9a2 100644
--- a/odk/docs/idl/idl_chapter_refs.txt
+++ b/odk/docs/idl/idl_chapter_refs.txt
@@ -3638,7 +3638,7 @@ TOPIC:
 com.sun.star.i18n.XExtendedCalendar
 
 LINK:Documentation/DevGuide/Drawings/Glue_Points_and_Connectors
-DESCR:Drawings - Glue Points and Connectors
+DESCR:Drawings - Gluepoints and Connectors
 REF:
 com.sun.star.drawing.ConnectorShape
 TOPIC:
diff --git a/odk/examples/DevelopersGuide/Drawing/GluePointDemo.java b/odk/examples/DevelopersGuide/Drawing/GluePointDemo.java
index f45ea385a099..0778216ae404 100644
--- a/odk/examples/DevelopersGuide/Drawing/GluePointDemo.java
+++ b/odk/examples/DevelopersGuide/Drawing/GluePointDemo.java
@@ -138,14 +138,14 @@ public class GluePointDemo
             aGluePoint.Position.X = 0;
             aGluePoint.Position.Y = 0;
 
-            // create and insert a glue point at shape1
+            // create and insert a gluepoint at shape1
             xGluePointsSupplier = UnoRuntime.queryInterface( XGluePointsSupplier.class, xShape1 );
             xIndexContainer = xGluePointsSupplier.getGluePoints();
             xIdentifierContainer = UnoRuntime.queryInterface( XIdentifierContainer.class,
                     xIndexContainer );
             int nIndexOfGluePoint1 = xIdentifierContainer.insert( aGluePoint );
 
-            // create and insert a glue point at shape2
+            // create and insert a gluepoint at shape2
             xGluePointsSupplier = UnoRuntime.queryInterface( XGluePointsSupplier.class, xShape2 );
             xIndexContainer = xGluePointsSupplier.getGluePoints();
             xIdentifierContainer = UnoRuntime.queryInterface( XIdentifierContainer.class,
diff --git a/odk/examples/DevelopersGuide/Drawing/Organigram.java b/odk/examples/DevelopersGuide/Drawing/Organigram.java
index 5a496086efbd..f87fb4cf9995 100644
--- a/odk/examples/DevelopersGuide/Drawing/Organigram.java
+++ b/odk/examples/DevelopersGuide/Drawing/Organigram.java
@@ -164,9 +164,9 @@ public class Organigram {
                     xConnectorProps.setPropertyValue("StartShape", xStartShape);
                     xConnectorProps.setPropertyValue("EndShape", xShape);
                     xConnectorProps.setPropertyValue("StartGluePointIndex",
-                                      Integer.valueOf(2)); // 2 = bottom glue point
+                                      Integer.valueOf(2)); // 2 = bottom gluepoint
                     xConnectorProps.setPropertyValue("EndGluePointIndex",
-                                      Integer.valueOf(0));   // 0 = top glue point
+                                      Integer.valueOf(0));   // 0 = top gluepoint
                 }
             }
         }
diff --git a/offapi/com/sun/star/drawing/ConnectorShape.idl b/offapi/com/sun/star/drawing/ConnectorShape.idl
index 61112ffe8701..f3272e11ebfd 100644
--- a/offapi/com/sun/star/drawing/ConnectorShape.idl
+++ b/offapi/com/sun/star/drawing/ConnectorShape.idl
@@ -62,7 +62,7 @@ published service ConnectorShape
     [property] com::sun::star::drawing::XShape StartShape;
 
 
-    /** this property holds the index of the glue point the start point of
+    /** this property holds the index of the gluepoint the start point of
         this connector is glued on.
     */
     [property] long StartGluePointIndex;
@@ -82,7 +82,7 @@ published service ConnectorShape
     [property] com::sun::star::drawing::XShape EndShape;
 
 
-    /** this property holds the index of the glue point the end point of
+    /** this property holds the index of the gluepoint the end point of
         this connector is glued on.
     */
     [property] com::sun::star::awt::Point EndPosition;
diff --git a/offapi/com/sun/star/drawing/EnhancedCustomShapeGluePointType.idl b/offapi/com/sun/star/drawing/EnhancedCustomShapeGluePointType.idl
index 9bc9091cf000..0d6acb66f50d 100644
--- a/offapi/com/sun/star/drawing/EnhancedCustomShapeGluePointType.idl
+++ b/offapi/com/sun/star/drawing/EnhancedCustomShapeGluePointType.idl
@@ -24,24 +24,24 @@
  module com {  module sun {  module star {  module drawing {
 
 
-/** defines which glue points are being offered by the EnhancedCustomShape
+/** defines which gluepoints are being offered by the EnhancedCustomShape
  */
 constants EnhancedCustomShapeGluePointType
 {
-    /** no glue points are offered
+    /** no gluepoints are offered
      */
     const short NONE = 0;
 
-    /** glue points are offered for each segment
+    /** gluepoints are offered for each segment
      */
     const short SEGMENTS = 1;
 
-    /** only glue points of the GluePoints property from the
+    /** only gluepoints of the GluePoints property from the
         com::sun:star::drawing::EnhancedCustomShapePath are offered
      */
     const short CUSTOM = 2;
 
-    /** standard top, left, right, bottom glue points are offered
+    /** standard top, left, right, bottom gluepoints are offered
      */
     const short RECT = 3;
  };
diff --git a/offapi/com/sun/star/drawing/EnhancedCustomShapePath.idl b/offapi/com/sun/star/drawing/EnhancedCustomShapePath.idl
index 4a80069e30e4..568365646b9a 100644
--- a/offapi/com/sun/star/drawing/EnhancedCustomShapePath.idl
+++ b/offapi/com/sun/star/drawing/EnhancedCustomShapePath.idl
@@ -59,7 +59,7 @@ service EnhancedCustomShapePath
     */
     [optional, property] sequence<::com::sun::star::drawing::EnhancedCustomShapeTextFrame> TextFrames;
 
-    /** This property specifies custom glue points
+    /** This property specifies custom gluepoints
     */
     [optional, property] sequence<::com::sun::star::drawing::EnhancedCustomShapeParameterPair> GluePoints;
 
diff --git a/offapi/com/sun/star/drawing/EscapeDirection.idl b/offapi/com/sun/star/drawing/EscapeDirection.idl
index a8f9f0d1b791..63c948eaa827 100644
--- a/offapi/com/sun/star/drawing/EscapeDirection.idl
+++ b/offapi/com/sun/star/drawing/EscapeDirection.idl
@@ -25,7 +25,7 @@
 
 
 /** This enumeration defines the escape direction a connector takes on
-    a glue point.
+    a gluepoint.
  */
 published enum EscapeDirection
 {
diff --git a/offapi/com/sun/star/drawing/GluePoint2.idl b/offapi/com/sun/star/drawing/GluePoint2.idl
index f600eb749a8f..916be1bf9fb3 100644
--- a/offapi/com/sun/star/drawing/GluePoint2.idl
+++ b/offapi/com/sun/star/drawing/GluePoint2.idl
@@ -27,13 +27,13 @@
  module com {  module sun {  module star {  module drawing {
 
 
-/** This struct defines the attributes of a glue point.
-    <p>A glue point is a position inside a drawing shape where an edge
+/** This struct defines the attributes of a gluepoint.
+    <p>A gluepoint is a position inside a drawing shape where an edge
     of a connector shape can be connected.</p>
  */
 published struct GluePoint2
 {
-    /** This is the position of this glue point. Depending on
+    /** This is the position of this gluepoint. Depending on
         the flag <code>IsRelative</code>, this is either in 1/100cm
         or in 1/100%.
 
@@ -41,13 +41,13 @@ published struct GluePoint2
      */
     com::sun::star::awt::Point Position;
 
-    /** if this flag is set to true, the position of this glue point
+    /** if this flag is set to true, the position of this gluepoint
         is given in 1/100% values instead of 1/100cm. */
     boolean IsRelative;
 
-    /** if this glue points position is not relative, this enum
+    /** if this gluepoints position is not relative, this enum
         specifies the vertical and horizontal alignment of this
-        point. The alignment specifies how the glue point is
+        point. The alignment specifies how the gluepoint is
         moved if the shape is resized. */
     com::sun::star::drawing::Alignment PositionAlignment;
 
@@ -58,7 +58,7 @@ published struct GluePoint2
     com::sun::star::drawing::EscapeDirection Escape;
 
     /** if this flag is set to false, this is a default glue
-        point. Some shapes may have default glue points attached
+        point. Some shapes may have default gluepoints attached
         to them which cannot be altered or removed. */
     boolean IsUserDefined;
 };
diff --git a/offapi/com/sun/star/drawing/Shape.idl b/offapi/com/sun/star/drawing/Shape.idl
index daa87b29e88c..7d6e9e22b39d 100644
--- a/offapi/com/sun/star/drawing/Shape.idl
+++ b/offapi/com/sun/star/drawing/Shape.idl
@@ -66,7 +66,7 @@ published service Shape
     interface com::sun::star::drawing::XShapeDescriptor;
 
 
-    /** This interfaces gives access to an optional container of glue points.
+    /** This interfaces gives access to an optional container of gluepoints.
         To have unique ids you should query the returned interface for
         com::sun::star::container::XIdentifierContainer.
     */
diff --git a/officecfg/registry/data/org/openoffice/Office/UI/DrawImpressCommands.xcu b/officecfg/registry/data/org/openoffice/Office/UI/DrawImpressCommands.xcu
index 1d73e546fcb9..7d0f7721ab42 100644
--- a/officecfg/registry/data/org/openoffice/Office/UI/DrawImpressCommands.xcu
+++ b/officecfg/registry/data/org/openoffice/Office/UI/DrawImpressCommands.xcu
@@ -214,10 +214,10 @@
       </node>
       <node oor:name=".uno:GlueEditMode" oor:op="replace">
         <prop oor:name="Label" oor:type="xs:string">
-          <value xml:lang="en-US">~Glue Points</value>
+          <value xml:lang="en-US">~Gluepoints</value>
         </prop>
         <prop oor:name="TooltipLabel" oor:type="xs:string">
-          <value xml:lang="en-US">Show Glue Points Functions</value>
+          <value xml:lang="en-US">Show Gluepoint Functions</value>
         </prop>
         <prop oor:name="Properties" oor:type="xs:int">
           <value>1</value>
@@ -225,7 +225,7 @@
       </node>
       <node oor:name=".uno:GlueInsertPoint" oor:op="replace">
         <prop oor:name="Label" oor:type="xs:string">
-          <value xml:lang="en-US">Insert Glue Point</value>
+          <value xml:lang="en-US">Insert Gluepoint</value>
         </prop>
         <prop oor:name="Properties" oor:type="xs:int">
           <value>1</value>
@@ -233,7 +233,7 @@
       </node>
       <node oor:name=".uno:GluePercent" oor:op="replace">
         <prop oor:name="Label" oor:type="xs:string">
-          <value xml:lang="en-US">Glue Point Relative</value>
+          <value xml:lang="en-US">Gluepoint Relative</value>
         </prop>
         <prop oor:name="Properties" oor:type="xs:int">
           <value>1</value>
@@ -246,7 +246,7 @@
       </node>
       <node oor:name=".uno:GlueHorzAlignCenter" oor:op="replace">
         <prop oor:name="Label" oor:type="xs:string">
-          <value xml:lang="en-US">Glue Point Horizontal Center</value>
+          <value xml:lang="en-US">Gluepoint Horizontal Center</value>
         </prop>
         <prop oor:name="Properties" oor:type="xs:int">
           <value>1</value>
@@ -254,7 +254,7 @@
       </node>
       <node oor:name=".uno:GlueHorzAlignLeft" oor:op="replace">
         <prop oor:name="Label" oor:type="xs:string">
-          <value xml:lang="en-US">Glue Point Horizontal Left</value>
+          <value xml:lang="en-US">Gluepoint Horizontal Left</value>
         </prop>
         <prop oor:name="Properties" oor:type="xs:int">
           <value>1</value>
@@ -262,7 +262,7 @@
       </node>
       <node oor:name=".uno:GlueHorzAlignRight" oor:op="replace">
         <prop oor:name="Label" oor:type="xs:string">
-          <value xml:lang="en-US">Glue Point Horizontal Right</value>
+          <value xml:lang="en-US">Gluepoint Horizontal Right</value>
         </prop>
         <prop oor:name="Properties" oor:type="xs:int">
           <value>1</value>
@@ -270,7 +270,7 @@
       </node>
       <node oor:name=".uno:GlueVertAlignCenter" oor:op="replace">
         <prop oor:name="Label" oor:type="xs:string">
-          <value xml:lang="en-US">Glue Point Vertical Center</value>
+          <value xml:lang="en-US">Gluepoint Vertical Center</value>
         </prop>
         <prop oor:name="Properties" oor:type="xs:int">
           <value>1</value>
@@ -278,7 +278,7 @@
       </node>
       <node oor:name=".uno:GlueVertAlignTop" oor:op="replace">
         <prop oor:name="Label" oor:type="xs:string">
-          <value xml:lang="en-US">Glue Point Vertical Top</value>
+          <value xml:lang="en-US">Gluepoint Vertical Top</value>
         </prop>
         <prop oor:name="Properties" oor:type="xs:int">
           <value>1</value>
@@ -286,7 +286,7 @@
       </node>
       <node oor:name=".uno:GlueVertAlignBottom" oor:op="replace">
         <prop oor:name="Label" oor:type="xs:string">
-          <value xml:lang="en-US">Glue Point Vertical Bottom</value>
+          <value xml:lang="en-US">Gluepoint Vertical Bottom</value>
         </prop>
         <prop oor:name="Properties" oor:type="xs:int">
           <value>1</value>
diff --git a/officecfg/registry/data/org/openoffice/Office/UI/DrawWindowState.xcu b/officecfg/registry/data/org/openoffice/Office/UI/DrawWindowState.xcu
index 33eb4cb2e8bd..8f820ad0ac88 100644
--- a/officecfg/registry/data/org/openoffice/Office/UI/DrawWindowState.xcu
+++ b/officecfg/registry/data/org/openoffice/Office/UI/DrawWindowState.xcu
@@ -67,7 +67,7 @@
       </node>
       <node oor:name="private:resource/popupmenu/gluepoint" oor:op="replace">
         <prop oor:name="UIName" oor:type="xs:string">
-          <value xml:lang="en-US">Glue Point</value>
+          <value xml:lang="en-US">Gluepoint</value>
         </prop>
       </node>
       <node oor:name="private:resource/popupmenu/graphic" oor:op="replace">
@@ -530,7 +530,7 @@
       </node>
       <node oor:name="private:resource/toolbar/gluepointsobjectbar" oor:op="replace">
         <prop oor:name="UIName" oor:type="xs:string">
-          <value xml:lang="en-US">Glue Points</value>
+          <value xml:lang="en-US">Gluepoints</value>
         </prop>
         <prop oor:name="DockPos" oor:type="xs:string">
           <value>1,0</value>
diff --git a/officecfg/registry/data/org/openoffice/Office/UI/ImpressWindowState.xcu b/officecfg/registry/data/org/openoffice/Office/UI/ImpressWindowState.xcu
index bd50af5c8671..234502d43185 100644
--- a/officecfg/registry/data/org/openoffice/Office/UI/ImpressWindowState.xcu
+++ b/officecfg/registry/data/org/openoffice/Office/UI/ImpressWindowState.xcu
@@ -67,7 +67,7 @@
       </node>
       <node oor:name="private:resource/popupmenu/gluepoint" oor:op="replace">
         <prop oor:name="UIName" oor:type="xs:string">
-          <value xml:lang="en-US">Glue Point</value>
+          <value xml:lang="en-US">Gluepoint</value>
         </prop>
       </node>
       <node oor:name="private:resource/popupmenu/graphic" oor:op="replace">
diff --git a/qadevOOo/tests/java/ifc/drawing/_XGluePointsSupplier.java b/qadevOOo/tests/java/ifc/drawing/_XGluePointsSupplier.java
index 8437143ab17a..c29963f5d7e2 100644
--- a/qadevOOo/tests/java/ifc/drawing/_XGluePointsSupplier.java
+++ b/qadevOOo/tests/java/ifc/drawing/_XGluePointsSupplier.java
@@ -36,7 +36,7 @@ public class _XGluePointsSupplier extends MultiMethodTest {
     public XGluePointsSupplier oObj = null;
 
     /**
-    * Gets glue points collection. <p>
+    * Gets gluepoints collection. <p>
     * Has <b> OK </b> status if the value returned is not null. <p>
     */
     public void _getGluePoints(){
diff --git a/sd/source/ui/dlg/gluectrl.cxx b/sd/source/ui/dlg/gluectrl.cxx
index 87ac30fb7cda..171d475c87af 100644
--- a/sd/source/ui/dlg/gluectrl.cxx
+++ b/sd/source/ui/dlg/gluectrl.cxx
@@ -47,7 +47,7 @@ const SdrEscapeDirection aEscDirArray[] =
 SFX_IMPL_TOOLBOX_CONTROL( SdTbxCtlGlueEscDir, SfxUInt16Item )
 
 /**
- * Constructor for glue point escape direction Listbox
+ * Constructor for gluepoint escape direction Listbox
  */
 GlueEscDirLB::GlueEscDirLB(vcl::Window* pParent, const Reference<XFrame>& rFrame)
     : InterimItemWindow(pParent, "modules/simpress/ui/gluebox.ui", "GlueBox")
@@ -131,7 +131,7 @@ void GlueEscDirLB::Fill()
 }
 
 /**
- * Constructor for glue point escape direction toolbox control
+ * Constructor for gluepoint escape direction toolbox control
  */
 SdTbxCtlGlueEscDir::SdTbxCtlGlueEscDir(
     sal_uInt16 nSlotId, ToolBoxItemId nId, ToolBox& rTbx ) :
diff --git a/sd/source/ui/func/fuconbez.cxx b/sd/source/ui/func/fuconbez.cxx
index 6ab9bf17c669..8c4219cf523c 100644
--- a/sd/source/ui/func/fuconbez.cxx
+++ b/sd/source/ui/func/fuconbez.cxx
@@ -167,7 +167,7 @@ bool FuConstructBezierPolygon::MouseButtonDown(const MouseEvent& rMEvt)
 
     if (eHit == SdrHitKind::MarkedObject && nEditMode == SID_BEZIER_INSERT)
     {
-        // insert glue point
+        // insert gluepoint
         mpView->BegInsObjPoint(aMDPos, rMEvt.IsMod1());
     }
     else
diff --git a/sd/source/ui/func/fuediglu.cxx b/sd/source/ui/func/fuediglu.cxx
index 6a793db7a60c..5d9d614479e9 100644
--- a/sd/source/ui/func/fuediglu.cxx
+++ b/sd/source/ui/func/fuediglu.cxx
@@ -115,12 +115,12 @@ bool FuEditGluePoints::MouseButtonDown(const MouseEvent& rMEvt)
         }
         else if (eHit == SdrHitKind::MarkedObject && mpView->IsInsGluePointMode())
         {
-            // insert glue points
+            // insert gluepoints
             mpView->BegInsGluePoint(aMDPos);
         }
         else if (eHit == SdrHitKind::MarkedObject && rMEvt.IsMod1())
         {
-            // select glue points
+            // select gluepoints
             if (!rMEvt.IsShift())
                 mpView->UnmarkAllGluePoints();
 
@@ -133,7 +133,7 @@ bool FuEditGluePoints::MouseButtonDown(const MouseEvent& rMEvt)
         }
         else if (eHit == SdrHitKind::Gluepoint)
         {
-            // select glue points
+            // select gluepoints
             if (!rMEvt.IsShift())
                 mpView->UnmarkAllGluePoints();
 
@@ -175,7 +175,7 @@ bool FuEditGluePoints::MouseButtonDown(const MouseEvent& rMEvt)
             }
             else if (mpView->AreObjectsMarked())
             {
-                // select glue point
+                // select gluepoint
                 if (!rMEvt.IsShift())
                     mpView->UnmarkAllGluePoints();
 
diff --git a/sd/source/ui/func/fusel.cxx b/sd/source/ui/func/fusel.cxx
index 37f3c15fe604..57d3bab073b6 100644
--- a/sd/source/ui/func/fusel.cxx
+++ b/sd/source/ui/func/fusel.cxx
@@ -468,14 +468,14 @@ bool FuSelection::MouseButtonDown(const MouseEvent& rMEvt)
         else if (eHit == SdrHitKind::MarkedObject && nEditMode == SID_BEZIER_INSERT)
         {
             /******************************************************************
-            * Insert glue point
+            * Insert gluepoint
             ******************************************************************/
             mpView->BegInsObjPoint(aMDPos, rMEvt.IsMod1());
         }
         else if (eHit == SdrHitKind::MarkedObject && rMEvt.IsMod1())
         {
             /******************************************************************
-            * Select glue point
+            * Select gluepoint
             ******************************************************************/
             if (!rMEvt.IsShift())
                 mpView->UnmarkAllPoints();
@@ -494,7 +494,7 @@ bool FuSelection::MouseButtonDown(const MouseEvent& rMEvt)
         else if (eHit == SdrHitKind::Handle)
         {
             /******************************************************************
-            * Select glue point
+            * Select gluepoint
             ******************************************************************/
             if (!mpView->IsPointMarked(*aVEvt.mpHdl) || rMEvt.IsShift())
             {
@@ -567,7 +567,7 @@ bool FuSelection::MouseButtonDown(const MouseEvent& rMEvt)
             else if (mpView->AreObjectsMarked())
             {
                 /**************************************************************
-                * Select glue point
+                * Select gluepoint
                 **************************************************************/
                 if (!rMEvt.IsShift())
                     mpView->UnmarkAllPoints();
diff --git a/sd/source/ui/view/drviews4.cxx b/sd/source/ui/view/drviews4.cxx
index bcfcc452713d..7e4932b29856 100644
--- a/sd/source/ui/view/drviews4.cxx
+++ b/sd/source/ui/view/drviews4.cxx
@@ -562,7 +562,7 @@ void DrawViewShell::Command(const CommandEvent& rCEvt, ::sd::Window* pWin)
         sal_uInt16  nHitLog = static_cast<sal_uInt16>(GetActiveWindow()->PixelToLogic(
             Size(FuPoor::HITPIX, 0 ) ).Width());
         sal_uInt16  nHelpLine;
-        // for glue points
+        // for gluepoints
         SdrObject*  pObj = nullptr;
         sal_uInt16      nPickId = 0;
         // for field command
@@ -577,7 +577,7 @@ void DrawViewShell::Command(const CommandEvent& rCEvt, ::sd::Window* pWin)
             ShowSnapLineContextMenu(*pPV, nHelpLine, rCEvt.GetMousePosPixel());
             return;
         }
-        // is glue point under cursor marked?
+        // is gluepoint under cursor marked?
         else if( mpDrawView->PickGluePoint( aMPos, pObj, nPickId, pPV ) &&
                  mpDrawView->IsGluePointMarked( pObj, nPickId ) )
         {
diff --git a/sd/source/ui/view/drviews7.cxx b/sd/source/ui/view/drviews7.cxx
index d9a1acf7ae99..1a362508beab 100644
--- a/sd/source/ui/view/drviews7.cxx
+++ b/sd/source/ui/view/drviews7.cxx
@@ -501,7 +501,7 @@ void DrawViewShell::GetMenuState( SfxItemSet &rSet )
         }
     }
 
-    // glue points
+    // gluepoints
     if( SfxItemState::DEFAULT == rSet.GetItemState( SID_GLUE_EDITMODE ) ||
         SfxItemState::DEFAULT == rSet.GetItemState( SID_GLUE_INSERT_POINT ) ||
         SfxItemState::DEFAULT == rSet.GetItemState( SID_GLUE_PERCENT ) ||
diff --git a/svx/source/engine3d/obj3d.cxx b/svx/source/engine3d/obj3d.cxx
index 83fd8c031311..4fa24809ae30 100644
--- a/svx/source/engine3d/obj3d.cxx
+++ b/svx/source/engine3d/obj3d.cxx
@@ -430,8 +430,8 @@ void E3dObject::RestoreGeoData(const SdrObjGeoData& rGeo)
 // is regardless of how the scene has been rotated up until now.
 void E3dObject::NbcRotate(const Point& rRef, Degree100 nAngle, double sn, double cs)
 {
-    // So currently the glue points are defined relative to the scene aOutRect.
-    // Before turning the glue points are defined relative to the page. They
+    // So currently the gluepoints are defined relative to the scene aOutRect.
+    // Before turning the gluepoints are defined relative to the page. They
     // take no part in the rotation of the scene. To ensure this, there is the
     // SetGlueReallyAbsolute(sal_True);
     double fAngleInRad = toRadians(nAngle);
@@ -441,7 +441,7 @@ void E3dObject::NbcRotate(const Point& rRef, Degree100 nAngle, double sn, double
     NbcSetTransform(aRotateZ * GetTransform());
 
     SetBoundAndSnapRectsDirty();    // This forces a recalculation of all BoundRects
-    NbcRotateGluePoints(rRef,nAngle,sn,cs);  // Rotate the glue points (who still
+    NbcRotateGluePoints(rRef,nAngle,sn,cs);  // Rotate the gluepoints (who still
                                             // have coordinates relative to the
                                             // original page)
     SetGlueReallyAbsolute(false);       // from now they are again relative to BoundRect (that is defined as aOutRect)
diff --git a/svx/source/engine3d/scene3d.cxx b/svx/source/engine3d/scene3d.cxx
index af91c52b1309..0a7253139330 100644
--- a/svx/source/engine3d/scene3d.cxx
+++ b/svx/source/engine3d/scene3d.cxx
@@ -609,8 +609,8 @@ void E3dScene::SetTransform(const basegfx::B3DHomMatrix& rMatrix)
 
 void E3dScene::NbcRotate(const Point& rRef, Degree100 nAngle, double sn, double cs)
 {
-    // So currently the glue points are defined relative to the scene aOutRect.
-    // Before turning the glue points are defined relative to the page. They
+    // So currently the gluepoints are defined relative to the scene aOutRect.
+    // Before turning the gluepoints are defined relative to the page. They
     // take no part in the rotation of the scene. To ensure this, there is the
     // SetGlueReallyAbsolute(sal_True);
 
@@ -628,7 +628,7 @@ void E3dScene::NbcRotate(const Point& rRef, Degree100 nAngle, double sn, double
     NbcSetTransform(aRotation * GetTransform());
 
     SetBoundAndSnapRectsDirty();    // This forces a recalculation of all BoundRects
-    NbcRotateGluePoints(rRef,nAngle,sn,cs);  // Rotate the glue points (who still
+    NbcRotateGluePoints(rRef,nAngle,sn,cs);  // Rotate the gluepoints (who still
                                             // have coordinates relative to the
                                             // original page)
     SetGlueReallyAbsolute(false);  // from now they are again relative to BoundRect (that is defined as aOutRect)
diff --git a/svx/source/inc/svdobjplusdata.hxx b/svx/source/inc/svdobjplusdata.hxx
index c5d0596bab29..5e00a37c57c6 100644
--- a/svx/source/inc/svdobjplusdata.hxx
+++ b/svx/source/inc/svdobjplusdata.hxx
@@ -25,7 +25,7 @@ class SdrObjPlusData final
 
     std::unique_ptr<SfxBroadcaster>      pBroadcast;    // broadcaster, if this object is referenced (bVirtObj=true). Also for connectors etc.
     std::unique_ptr<SdrObjUserDataList>  pUserDataList; // application specific data
-    std::unique_ptr<SdrGluePointList>    pGluePoints;   // glue points for glueing object connectors
+    std::unique_ptr<SdrGluePointList>    pGluePoints;   // gluepoints for glueing object connectors
 
     // #i68101#
     // object name, title and description
diff --git a/svx/source/svdraw/svdcrtv.cxx b/svx/source/svdraw/svdcrtv.cxx
index 67820ff1d732..9d6dc71b7d4f 100644
--- a/svx/source/svdraw/svdcrtv.cxx
+++ b/svx/source/svdraw/svdcrtv.cxx
@@ -81,7 +81,7 @@ ImplConnectMarkerOverlay::ImplConnectMarkerOverlay(const SdrCreateView& rView, S
             xTargetOverlay->add(*pNew);
             maObjects.append(std::move(pNew));
 
-            // glue points
+            // gluepoints
             for(sal_uInt16 i(0); i < 4; i++)
             {
                 SdrGluePoint aGluePoint(rObject.GetVertexGluePoint(i));
diff --git a/svx/source/svdraw/svddrgmt.cxx b/svx/source/svdraw/svddrgmt.cxx
index 17376206f8a7..5917d1475c44 100644
--- a/svx/source/svdraw/svddrgmt.cxx
+++ b/svx/source/svdraw/svddrgmt.cxx
@@ -1621,7 +1621,7 @@ void SdrDragMove::MoveSdrDrag(const Point& rNoSnapPnt_)
     }
 
     if (getSdrDragView().IsDraggingGluePoints())
-    { // restrict glue points to the BoundRect of the Obj
+    { // restrict gluepoints to the BoundRect of the Obj
         aPt1-=DragStat().GetStart();
         const SdrMarkList& rML=GetMarkedObjectList();
         const size_t nMarkCount=rML.GetMarkCount();
diff --git a/svx/source/svdraw/svddrgv.cxx b/svx/source/svdraw/svddrgv.cxx
index b5a8025a51d5..b6ac05cef7c1 100644
--- a/svx/source/svdraw/svddrgv.cxx
+++ b/svx/source/svdraw/svddrgv.cxx
@@ -619,7 +619,7 @@ void SdrDragView::BrkDragObj()
 
     if (IsInsertGluePoint())
     {
-        mpInsPointUndo->Undo(); // delete inserted glue point again
+        mpInsPointUndo->Undo(); // delete inserted gluepoint again
         delete mpInsPointUndo;
         mpInsPointUndo=nullptr;
         SetInsertGluePoint(false);
@@ -781,7 +781,7 @@ bool SdrDragView::BegInsGluePoint(const Point& rPnt)
         }
         else
         {
-            // no glue points possible for this object (e. g. Edge)
+            // no gluepoints possible for this object (e. g. Edge)
             SetInsertGluePoint(false);
             delete mpInsPointUndo;
             mpInsPointUndo=nullptr;
diff --git a/svx/source/svdraw/svdglue.cxx b/svx/source/svdraw/svdglue.cxx
index 59576ea01a69..7f25074cf425 100644
--- a/svx/source/svdraw/svdglue.cxx
+++ b/svx/source/svdraw/svdglue.cxx
@@ -290,8 +290,8 @@ SdrGluePointList& SdrGluePointList::operator=(const SdrGluePointList& rSrcList)
     return *this;
 }
 
-// The ID's of the glue points always increase monotonously!
-// If an ID is taken already, the new glue point gets a new ID. ID 0 is reserved.
+// The ID's of the gluepoints always increase monotonously!
+// If an ID is taken already, the new gluepoint gets a new ID. ID 0 is reserved.
 sal_uInt16 SdrGluePointList::Insert(const SdrGluePoint& rGP)
 {
     SdrGluePoint aGP(rGP);
diff --git a/svx/source/svdraw/svdhdl.cxx b/svx/source/svdraw/svdhdl.cxx
index 85d46f99a00e..ed0331c24a38 100644
--- a/svx/source/svdraw/svdhdl.cxx
+++ b/svx/source/svdraw/svdhdl.cxx
@@ -1041,7 +1041,7 @@ bool SdrHdl::IsFocusHdl() const
         case SdrHdlKind::Circle:      // angle of circle segments, corner radius of rectangles
         case SdrHdlKind::Ref1:      // reference point 1, e. g. center of rotation
         case SdrHdlKind::Ref2:      // reference point 2, e. g. endpoint of reflection axis
-        case SdrHdlKind::Glue:      // glue point
+        case SdrHdlKind::Glue:      // gluepoint
 
         // for SJ and the CustomShapeHandles:
         case SdrHdlKind::CustomShape1:
diff --git a/svx/source/svdraw/svdmrkv.cxx b/svx/source/svdraw/svdmrkv.cxx
index 442719ad15e8..456ffd30f7fd 100644
--- a/svx/source/svdraw/svdmrkv.cxx
+++ b/svx/source/svdraw/svdmrkv.cxx
@@ -1792,7 +1792,7 @@ void SdrMarkView::CheckMarked()
         }
         else
         {
-            if (!IsGluePointEditMode()) { // selected glue points only in GlueEditMode
+            if (!IsGluePointEditMode()) { // selected gluepoints only in GlueEditMode
                 SdrUShortCont& rPts = pM->GetMarkedGluePoints();
                 rPts.clear();
             }
diff --git a/svx/source/svdraw/svdmrkv1.cxx b/svx/source/svdraw/svdmrkv1.cxx
index 89ec0c5dc199..0c32aefcfd11 100644
--- a/svx/source/svdraw/svdmrkv1.cxx
+++ b/svx/source/svdraw/svdmrkv1.cxx
@@ -322,7 +322,7 @@ void SdrMarkView::UndirtyMrkPnt() const
             SdrUShortCont& rPts = pM->GetMarkedGluePoints();
             const SdrGluePointList* pGPL=pObj->GetGluePointList();
             if (pGPL!=nullptr) {
-                // Remove invalid selected glue points, that is, all entries
+                // Remove invalid selected gluepoints, that is, all entries
                 // (IDs) that aren't contained in the GluePointList of the
                 // object
                 for(SdrUShortCont::const_iterator it = rPts.begin(); it != rPts.end(); )
@@ -337,7 +337,7 @@ void SdrMarkView::UndirtyMrkPnt() const
                 }
             } else {
                 if (!rPts.empty()) {
-                    rPts.clear(); // object doesn't have any glue points (any more)
+                    rPts.clear(); // object doesn't have any gluepoints (any more)
                     bChg=true;
                 }
             }
diff --git a/svx/source/svdraw/svdobj.cxx b/svx/source/svdraw/svdobj.cxx
index 27c2fb50b6c2..05f7712c0431 100644
--- a/svx/source/svdraw/svdobj.cxx
+++ b/svx/source/svdraw/svdobj.cxx
@@ -1912,7 +1912,7 @@ void SdrObject::SaveGeoData(SdrObjGeoData& rGeo) const
     rGeo.bClosedObj    =m_bClosedObj    ;
     rGeo.mnLayerID = mnLayerID;
 
-    // user-defined glue points
+    // user-defined gluepoints
     if (m_pPlusData!=nullptr && m_pPlusData->pGluePoints!=nullptr) {
         if (rGeo.pGPL!=nullptr) {
             *rGeo.pGPL=*m_pPlusData->pGluePoints;
@@ -1936,7 +1936,7 @@ void SdrObject::RestoreGeoData(const SdrObjGeoData& rGeo)
     m_bClosedObj    =rGeo.bClosedObj    ;
     mnLayerID = rGeo.mnLayerID;
 
-    // user-defined glue points
+    // user-defined gluepoints
     if (rGeo.pGPL!=nullptr) {
         ImpForcePlusData();
         if (m_pPlusData->pGluePoints!=nullptr) {
@@ -2303,7 +2303,7 @@ SdrGluePointList* SdrObject::ForceGluePointList()
 
 void SdrObject::SetGlueReallyAbsolute(bool bOn)
 {
-    // First a const call to see whether there are any glue points.
+    // First a const call to see whether there are any gluepoints.
     // Force const call!
     if (GetGluePointList()!=nullptr) {
         SdrGluePointList* pGPL=ForceGluePointList();
@@ -2313,7 +2313,7 @@ void SdrObject::SetGlueReallyAbsolute(bool bOn)
 
 void SdrObject::NbcRotateGluePoints(const Point& rRef, Degree100 nAngle, double sn, double cs)
 {
-    // First a const call to see whether there are any glue points.
+    // First a const call to see whether there are any gluepoints.
     // Force const call!
     if (GetGluePointList()!=nullptr) {
         SdrGluePointList* pGPL=ForceGluePointList();
@@ -2323,7 +2323,7 @@ void SdrObject::NbcRotateGluePoints(const Point& rRef, Degree100 nAngle, double
 
 void SdrObject::NbcMirrorGluePoints(const Point& rRef1, const Point& rRef2)
 {
-    // First a const call to see whether there are any glue points.
+    // First a const call to see whether there are any gluepoints.
     // Force const call!
     if (GetGluePointList()!=nullptr) {
         SdrGluePointList* pGPL=ForceGluePointList();
@@ -2333,7 +2333,7 @@ void SdrObject::NbcMirrorGluePoints(const Point& rRef1, const Point& rRef2)
 
 void SdrObject::NbcShearGluePoints(const Point& rRef, double tn, bool bVShear)
 {
-    // First a const call to see whether there are any glue points.
+    // First a const call to see whether there are any gluepoints.
     // Force const call!
     if (GetGluePointList()!=nullptr) {
         SdrGluePointList* pGPL=ForceGluePointList();
diff --git a/svx/source/svdraw/svdview.cxx b/svx/source/svdraw/svdview.cxx
index f61c1cb7c852..37dc5a8bb1c8 100644
--- a/svx/source/svdraw/svdview.cxx
+++ b/svx/source/svdraw/svdview.cxx
@@ -336,7 +336,7 @@ SdrHitKind SdrView::PickAnything(const Point& rLogicPos, SdrViewEvent& rVEvt) co
     }
     else if (bGluePointMode && PickGluePoint(aLocalLogicPosition,pObj,nGlueId,pPV))
     {
-        eHit=SdrHitKind::Gluepoint; // deselected glue point hit
+        eHit=SdrHitKind::Gluepoint; // deselected gluepoint hit
     }
     else if ((pHitObj = PickObj(aLocalLogicPosition,mnHitTolLog,pPV,SdrSearchOptions::DEEP|SdrSearchOptions::MARKED,&pObj,&bHitPassDirect)))
     {
@@ -805,7 +805,7 @@ bool SdrView::DoMouseEvent(const SdrViewEvent& rVEvt)
             if (!MarkObj(aLogicPos, mnHitTolLog, rVEvt.mbAddMark))
             {
                 // No object hit. Do the following:
-                // 1. deselect any selected glue points
+                // 1. deselect any selected gluepoints
                 // 2. deselect any selected polygon points
                 // 3. deselect any selected objects
                 if (!rVEvt.mbAddMark) UnmarkAll();
diff --git a/svx/source/unodraw/gluepts.cxx b/svx/source/unodraw/gluepts.cxx
index fcc381a95451..0467bc46d1eb 100644
--- a/svx/source/unodraw/gluepts.cxx
+++ b/svx/source/unodraw/gluepts.cxx
@@ -209,7 +209,7 @@ sal_Int32 SAL_CALL SvxUnoGluePointAccess::insert( const uno::Any& aElement )
         SdrGluePointList* pList = mpObject->ForceGluePointList();
         if( pList )
         {
-            // second, insert the new glue point
+            // second, insert the new gluepoint
             drawing::GluePoint2 aUnoGlue;
 
             if( aElement >>= aUnoGlue )
@@ -279,7 +279,7 @@ void SAL_CALL SvxUnoGluePointAccess::replaceByIdentifer( sal_Int32 Identifier, c
     {
         if( (*pList)[i].GetId() == nId )
         {
-            // change the glue point
+            // change the gluepoint
             SdrGluePoint& rTempPoint = (*pList)[i];
             convert( aGluePoint, rTempPoint );
 
@@ -301,7 +301,7 @@ uno::Any SAL_CALL SvxUnoGluePointAccess::getByIdentifier( sal_Int32 Identifier )
     {
         struct drawing::GluePoint2 aGluePoint;
 
-        if( Identifier < NON_USER_DEFINED_GLUE_POINTS ) // default glue point?
+        if( Identifier < NON_USER_DEFINED_GLUE_POINTS ) // default gluepoint?
         {
             SdrGluePoint aTempPoint = mpObject->GetVertexGluePoint( static_cast<sal_uInt16>(Identifier) );
             aGluePoint.IsUserDefined = false;
@@ -449,8 +449,8 @@ sal_Int32 SAL_CALL SvxUnoGluePointAccess::getCount()
     sal_Int32 nCount = 0;
     if( mpObject.is() )
     {
-        // each node has a default of 4 glue points
-        // and any number of user defined glue points
+        // each node has a default of 4 gluepoints
+        // and any number of user defined gluepoints
         nCount += 4;
 
         const SdrGluePointList* pList = mpObject->GetGluePointList();
@@ -467,7 +467,7 @@ uno::Any SAL_CALL SvxUnoGluePointAccess::getByIndex( sal_Int32 Index )
     {
         struct drawing::GluePoint2 aGluePoint;
 
-        if( Index < 4 ) // default glue point?
+        if( Index < 4 ) // default gluepoint?
         {
             SdrGluePoint aTempPoint = mpObject->GetVertexGluePoint( static_cast<sal_uInt16>(Index) );
             aGluePoint.IsUserDefined = false;
diff --git a/xmloff/source/draw/shapeexport.cxx b/xmloff/source/draw/shapeexport.cxx
index 8c7ba1727a84..c00886f386e8 100644
--- a/xmloff/source/draw/shapeexport.cxx
+++ b/xmloff/source/draw/shapeexport.cxx
@@ -1270,7 +1270,7 @@ void XMLShapeExport::ImpCalcShapeType(const uno::Reference< drawing::XShape >& x
     }
 }
 
-/** exports all user defined glue points */
+/** exports all user defined gluepoints */
 void XMLShapeExport::ImpExportGluePoints( const uno::Reference< drawing::XShape >& xShape )
 {
     uno::Reference< drawing::XGluePointsSupplier > xSupplier( xShape, uno::UNO_QUERY );
@@ -1289,7 +1289,7 @@ void XMLShapeExport::ImpExportGluePoints( const uno::Reference< drawing::XShape
     {
         if( (xGluePoints->getByIdentifier( nIdentifier ) >>= aGluePoint) && aGluePoint.IsUserDefined )
         {
-            // export only user defined glue points
+            // export only user defined gluepoints
 
             const OUString sId( OUString::number( nIdentifier ) );
             mrExport.AddAttribute(XML_NAMESPACE_DRAW, XML_ID, sId );
diff --git a/include/xmloff/shapeimport.hxx b/include/xmloff/shapeimport.hxx
index 51bc59a25d1f..12cb9f8fd581 100644
--- a/include/xmloff/shapeimport.hxx
+++ b/include/xmloff/shapeimport.hxx
@@ -220,16 +220,16 @@ public:
                              const OUString& rDestShapeId,
                              sal_Int32 nDestGlueId );
 
-    /** adds a mapping for a glue point identifier from an xml file to the identifier created after inserting
-        the new glue point into the core. The saved mappings can be retrieved by getGluePointId() */
+    /** adds a mapping for a gluepoint identifier from an xml file to the identifier created after inserting
+        the new gluepoint into the core. The saved mappings can be retrieved by getGluePointId() */
     void addGluePointMapping( css::uno::Reference< css::drawing::XShape > const & xShape,
                               sal_Int32 nSourceId, sal_Int32 nDestinnationId );
 
     /** moves all current DestinationId's for rXShape by n */
     void moveGluePointMapping( const css::uno::Reference< css::drawing::XShape >& xShape, const sal_Int32 n );
 
-    /** retrieves a mapping for a glue point identifier from the current xml file to the identifier created after
-        inserting the new glue point into the core. The mapping must be initialized first with addGluePointMapping() */
+    /** retrieves a mapping for a gluepoint identifier from the current xml file to the identifier created after
+        inserting the new gluepoint into the core. The mapping must be initialized first with addGluePointMapping() */
     sal_Int32 getGluePointId( const css::uno::Reference< css::drawing::XShape >& xShape, sal_Int32 nSourceId );
 
     /** this method must be calling before the first shape is imported for the given page.
diff --git a/svx/source/svdraw/svdoedge.cxx b/svx/source/svdraw/svdoedge.cxx
index c48d954c9ace..45e4329a54a8 100644
--- a/svx/source/svdraw/svdoedge.cxx
+++ b/svx/source/svdraw/svdoedge.cxx
@@ -460,12 +460,12 @@ SdrGluePoint SdrEdgeObj::GetCornerGluePoint(sal_uInt16 nNum) const
 
 const SdrGluePointList* SdrEdgeObj::GetGluePointList() const
 {
-    return nullptr; // no user defined glue points for connectors
+    return nullptr; // no user defined gluepoints for connectors
 }
 
 SdrGluePointList* SdrEdgeObj::ForceGluePointList()
 {
-    return nullptr; // no user defined glue points for connectors
+    return nullptr; // no user defined gluepoints for connectors
 }
 
 void SdrEdgeObj::ConnectToNode(bool bTail1, SdrObject* pObj)
@@ -2553,10 +2553,10 @@ void SdrEdgeObj::SetTailPoint( bool bTail, const Point& rPt )
     SetChanged();
 }
 
 /** this method is used by the api to set a glue point for a connection
     nId == -1 :     The best default point is automatically chosen
     0 <= nId <= 3 : One of the default points is chosen
-    nId >= 4 :      A user defined glue point is chosen
+    nId >= 4 :      A user defined gluepoint is chosen
 */
 void SdrEdgeObj::setGluePointIndex( bool bTail, sal_Int32 nIndex /* = -1 */ )
 {
@@ -2570,7 +2570,7 @@ void SdrEdgeObj::setGluePointIndex( bool bTail, sal_Int32 nIndex /* = -1 */ )
     {
         nIndex -= 3;        // the start api index is 0, whereas the implementation in svx starts from 1
 
-        // for user defined glue points we have
+        // for user defined gluepoints we have
         // to get the id for this index first
         const SdrGluePointList* pList = rConn1.GetObject() ? rConn1.GetObject()->GetGluePointList() : nullptr;
         if( pList == nullptr || SDRGLUEPOINT_NOTFOUND == pList->FindGluePoint(static_cast<sal_uInt16>(nIndex)) )
@@ -2588,7 +2588,7 @@ void SdrEdgeObj::setGluePointIndex( bool bTail, sal_Int32 nIndex /* = -1 */ )
     ImpRecalcEdgeTrack();
 }
 
 /** this method is used by the api to return a glue point id for a connection.
     See setGluePointId for possible return values */
 sal_Int32 SdrEdgeObj::getGluePointIndex( bool bTail )
 {
@@ -2553,10 +2553,10 @@ void SdrEdgeObj::SetTailPoint( bool bTail, const Point& rPt )
 }
 
-/** this method is used by the api to set a glue point for a connection
+/** this method is used by the api to set a gluepoint for a connection
     nId == -1 :     The best default point is automatically chosen
     0 <= nId <= 3 : One of the default points is chosen
@@ -2588,7 +2588,7 @@ void SdrEdgeObj::setGluePointIndex( bool bTail, sal_Int32 nIndex /* = -1 */ )
 }
 
-/** this method is used by the api to return a glue point id for a connection.
+/** this method is used by the api to return a gluepoint id for a connection.
     See setGluePointId for possible return values */
 sal_Int32 SdrEdgeObj::getGluePointIndex( bool bTail )
diff --git a/xmloff/source/draw/shapeimport.cxx b/xmloff/source/draw/shapeimport.cxx
index f0886de65d2a..ba4a5646c90f 100644
--- a/xmloff/source/draw/shapeimport.cxx
+++ b/xmloff/source/draw/shapeimport.cxx
@@ -71,8 +71,8 @@ struct ConnectionHint
 
 }
 
-/** this map store all glue point id mappings for shapes that had user defined glue points. This
-    is needed because on insertion the glue points will get a new and unique id */
+/** this map store all gluepoint id mappings for shapes that had user defined gluepoints. This
+    is needed because on insertion the gluepoints will get a new and unique id */
 typedef std::map<sal_Int32,sal_Int32> GluePointIdMap;
 typedef std::unordered_map< css::uno::Reference < css::drawing::XShape >, GluePointIdMap > ShapeGluePointsMap;
 
@@ -847,8 +847,8 @@ SvXMLImportPropertyMapper* XMLShapeImportHelper::CreateShapePropMapper( const un
     return pResult;
 }
 
-/** adds a mapping for a glue point identifier from an xml file to the identifier created after inserting
-    the new glue point into the core. The saved mappings can be retrieved by getGluePointId() */
+/** adds a mapping for a gluepoint identifier from an xml file to the identifier created after inserting
+    the new gluepoint into the core. The saved mappings can be retrieved by getGluePointId() */
 void XMLShapeImportHelper::addGluePointMapping( css::uno::Reference< css::drawing::XShape > const & xShape,
                           sal_Int32 nSourceId, sal_Int32 nDestinnationId )
 {
@@ -873,8 +873,8 @@ void XMLShapeImportHelper::moveGluePointMapping( const css::uno::Reference< css:
     }
 }
 
-/** retrieves a mapping for a glue point identifier from the current xml file to the identifier created after
-    inserting the new glue point into the core. The mapping must be initialized first with addGluePointMapping() */
+/** retrieves a mapping for a gluepoint identifier from the current xml file to the identifier created after
+    inserting the new gluepoint into the core. The mapping must be initialized first with addGluePointMapping() */
 sal_Int32 XMLShapeImportHelper::getGluePointId( const css::uno::Reference< css::drawing::XShape >& xShape, sal_Int32 nSourceId )
 {
     if( mpPageContext )
diff --git a/xmloff/source/draw/ximpshap.cxx b/xmloff/source/draw/ximpshap.cxx
index 09dfc2ca7645..8b395ddd9757 100644
--- a/xmloff/source/draw/ximpshap.cxx
+++ b/xmloff/source/draw/ximpshap.cxx
@@ -241,7 +241,7 @@ css::uno::Reference< css::xml::sax::XFastContextHandler > SdXMLShapeContext::cre
 
 void SdXMLShapeContext::addGluePoint( const uno::Reference< xml::sax::XFastAttributeList>& xAttrList )
 {
     // get the glue points container for this shape if it's not already there
     if( !mxGluePoints.is() )
     {
         uno::Reference< drawing::XGluePointsSupplier > xSupplier( mxShape, uno::UNO_QUERY );
@@ -311,7 +311,7 @@ void SdXMLShapeContext::addGluePoint( const uno::Reference< xml::sax::XFastAttri
         }
         catch(const uno::Exception&)
         {
-            DBG_UNHANDLED_EXCEPTION( "xmloff", "during setting of glue points");
+            DBG_UNHANDLED_EXCEPTION( "xmloff", "during setting of gluepoints");
         }
     }
 }
@@ -241,7 +241,7 @@ css::uno::Reference< css::xml::sax::XFastContextHandler > SdXMLShapeContext::cre
 void SdXMLShapeContext::addGluePoint( const uno::Reference< xml::sax::XFastAttributeList>& xAttrList )
 {
-    // get the glue points container for this shape if it's not already there
+    // get the gluepoints container for this shape if it's not already there
     if( !mxGluePoints.is() )
     {


More information about the Libreoffice-commits mailing list